clojure.core.typed

This namespace contains typed wrapper macros, type aliases and functions for type checking Clojure code. check-ns is the interface for checking namespaces, cf for checking individual forms.

This namespace contains typed wrapper macros, type aliases
and functions for type checking Clojure code. check-ns is the interface
for checking namespaces, cf for checking individual forms.
raw docstring

clojure.core.typed.hole

This namespace contains easy tools for hole driven development

This namespace contains easy tools for hole driven development
raw docstring

clojure.core.typed.util-vars

No vars found in this namespace.

cljdoc builds & hosts documentation for Clojure/Script libraries