typed.clj.runtime.hmap-utils

Utilities for HMap validation shared across projects.

Utilities for HMap validation shared across projects.
raw docstring

typed.clojure

Wrapper macros that do the right thing for each platform. See typed.clojure.jvm for jvm-specific ops.

Wrapper macros that do the right thing for each platform.
See typed.clojure.jvm for jvm-specific ops.
raw docstring

typed.clojure.jvm

JVM-specific annotations and operations. See typed.clojure for cross-platform ops.

JVM-specific annotations and operations.
See typed.clojure for cross-platform ops.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries