Utilities for HMap validation shared across projects.
Utilities for HMap validation shared across projects.
(valid-hmap-key-value? val)Returns true if value is valid for use as an HMap key. Valid keys exclude NaN and regex patterns.
Returns true if value is valid for use as an HMap key. Valid keys exclude NaN and regex patterns.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |