typed.clojure

Wrapper macros that do the right thing for each platform. See typed.clojure.jvm for jvm-specific ops.

Wrapper macros that do the right thing for each platform.
See typed.clojure.jvm for jvm-specific ops.
raw docstring

anncljmacro

(ann varsym typesyn)

Annotate varsym with type. If unqualified, qualify in the current namespace. If varsym has metadata {:no-check true}, ignore definitions of varsym while type checking. Supports namespace aliases and fully qualified namespaces to annotate vars in other namespaces.

eg. ; annotate the var foo in this namespace (ann foo [Number -> Number])

; annotate a var in another namespace
(ann another.ns/bar [-> nil])

; don't check this var
(ann ^:no-check foobar [Integer -> String])
Annotate varsym with type. If unqualified, qualify in the current namespace.
If varsym has metadata {:no-check true}, ignore definitions of varsym 
while type checking. Supports namespace aliases and fully qualified namespaces
to annotate vars in other namespaces.

eg. ; annotate the var foo in this namespace
    (ann foo [Number -> Number])

    ; annotate a var in another namespace
    (ann another.ns/bar [-> nil])
 
    ; don't check this var
    (ann ^:no-check foobar [Integer -> String])
sourceraw docstring

ann-datatypecljmacro

(ann-datatype & args)
source

ann-formcljmacro

(ann-form & args)
source

ann-manycljmacro

(ann-many & args)
source

ann-protocolcljmacro

(ann-protocol & args)
source

ann-recordcljmacro

(ann-record & args)
source

atomcljmacro

(atom & args)

Like atom, but with optional type annotations.

Same as (atom (ann-form init t) args*)

eg. (atom 1) : (Atom (Value 1)) (atom :- Num, 1) : (Atom Num)

Like atom, but with optional type annotations.

Same as (atom (ann-form init t) args*)

eg. (atom 1) : (Atom (Value 1))
    (atom :- Num, 1) : (Atom Num)
sourceraw docstring

cfcljmacro

(cf & args)

In Clojure, expands to (clojure.core.typed/cf ~@args). In ClojureScript JVM, expands to (cljs.core.typed/cf ~@args).

In Clojure, expands to (clojure.core.typed/cf ~@args).
In ClojureScript JVM, expands to (cljs.core.typed/cf ~@args).
sourceraw docstring

cf-cljcljmacro

(cf-clj & args)

Check a Clojure form in the current ns.

Check a Clojure form in the current *ns*.
sourceraw docstring

check-dir-cljclj

(check-dir-clj dirs)
source

check-ns-cljclj

(check-ns-clj)
(check-ns-clj ns-or-syms & {:as opt})

In Clojure, checks the current namespace or provided namespaces. Similar for self-hosted ClojureScript, except for macros namespaces.

In Clojure, checks the current namespace or provided namespaces.
Similar for self-hosted ClojureScript, except for macros namespaces.
sourceraw docstring

cnscljmacro

(cns & args)

In Clojure, expands to (check-ns-clj ~@args). In ClojureScript JVM, emulates calling (check-ns-cljs ~@args) at expansion time (note: args will not be evaluated). Self hosted ClojureScript semantics TBD.

Only suitable for REPL development:

  1. (t/cns) or (t/cns 'my-ns.foo)
  2. Fix type errors, save file, go back to 1 until fixed.

Not compatible with AOT compilation.

In Clojure, expands to (check-ns-clj ~@args).
In ClojureScript JVM, emulates calling (check-ns-cljs ~@args) at expansion time
(note: args will not be evaluated).
Self hosted ClojureScript semantics TBD.

Only suitable for REPL development:
1. (t/cns) or (t/cns 'my-ns.foo)
2. Fix type errors, save file, go back to 1 until fixed.

Not compatible with AOT compilation.
sourceraw docstring

declare-alias-kindcljmacro

(declare-alias-kind & args)
source

declare-datatypescljmacro

(declare-datatypes & args)
source

declare-namescljmacro

(declare-names & args)
source

declare-protocolscljmacro

(declare-protocols & args)
source

defcljmacro

(def & args)
source

defaliascljmacro

(defalias & args)
source

defncljmacro

(defn & args)
source

defprotocolcljmacro

(defprotocol & args)
source

doc-cljcljmacro

(doc-clj syn)

Pass any syntax fragment related to Typed Clojure to print documentation on it. eg., (doc-clj t/Rec) (doc-clj '[]) (doc-clj +) ;; print var annotation (doc-clj MyAlias) ;; print defalias mapping

Use :doc/index for documentation index.

Pass any syntax fragment related to Typed Clojure to print documentation on it.
eg., (doc-clj t/Rec)
     (doc-clj '[])
     (doc-clj +) ;; print var annotation
     (doc-clj MyAlias) ;; print defalias mapping

Use :doc/index for documentation index.
sourceraw docstring

fncljmacro

(fn & args)
source

instcljmacro

(inst & args)
source

inst-ctorcljmacro

(inst-ctor & args)
source

loopcljmacro

(loop & args)
source

refcljmacro

(ref & args)
source

tc-ignorecljmacro

(tc-ignore & args)
source

cljdoc builds & hosts documentation for Clojure/Script libraries