This namespace contains typed wrapper macros, type aliases and functions for type checking Clojure code. check-ns is the interface for checking namespaces, cf for checking individual forms.
This namespace contains typed wrapper macros, type aliases and functions for type checking Clojure code. check-ns is the interface for checking namespaces, cf for checking individual forms.
A contract system a la racket/contract.
Main entry point is the contract macro.
A contract system a la racket/contract. Main entry point is the `contract` macro.
This namespace contains easy tools for hole driven development
This namespace contains easy tools for hole driven development
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |